
# Type: gene as a model of disease association_subject




URI: [biolink:gene_as_a_model_of_disease_association_subject](https://w3id.org/biolink/vocab/gene_as_a_model_of_disease_association_subject)


## Domain and Range

[GeneAsAModelOfDiseaseAssociation](GeneAsAModelOfDiseaseAssociation.md) ->  <sub>REQ</sub> [GeneOrGeneProduct](GeneOrGeneProduct.md)

## Parents

 *  is_a: [gene to disease association➞subject](gene_to_disease_association_subject.md)

## Children


## Used by

 * [GeneAsAModelOfDiseaseAssociation](GeneAsAModelOfDiseaseAssociation.md)
